@@ -2,12 +2,18 @@
 
 files=
 line="none"
+force=/bin/false
 
 if [ $# = 0 ]; then
-	echo 'usage: B [-nnnn] files...'  1>&2
+	echo 'usage: B [-f[a]] [-nnnn] files...'  1>&2
 	exit 1
 fi
 
+case $1 in
+	-f)  force=/bin/true; auto=/bin/false; shift;;
+	-fa) force=/bin/true; auto=/bin/true;  shift;;
+esac
+
 dir=`/bin/pwd`
 if [ "$USER" = "" ]; then
 	USER=$LOGNAME
@@ -33,8 +39,19 @@ case "$DISPLAY" in
 			;;
 esac
 if [ ! -r $pipe ]; then
-	echo `basename $0`": No pipe \""$pipe"\" to sam." 1>&2
-	exit 1
+	if $force; then
+		if $auto; then
+			case "$DISPLAY" in
+				"") exec sam -d "$@";;
+				*)  exec sam "$@" & ;;
+			esac
+		else
+			exec sam "$@"
+		fi
+	else
+		echo `basename $0`": No pipe \""$pipe"\" to sam." 1>&2
+		exit 1
+	fi
 fi
 
 for i in $*
